﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using DevComponents.DotNetBar;
using SadrPosScale;
using System.IO.Ports;

namespace SadrPosScaleSoftware
{
    public partial class MainForm : Office2007Form
    {
        public PosScaleDevice PosScale = null;
        public MainForm()
        {
            InitializeComponent();
            Disposed += MainForm_Disposed;
        }

        private void MainForm_Disposed(object sender, EventArgs e)
        {
            try
            {
                PosScale.Dispose();
            }
            catch { }
        }

        private void btnConnect_Click(object sender, EventArgs e)
        {
            try
            {
                PosScale = new PosScaleDevice(PortNameList.Text, 9600);
                PosScale.ConnectToScale();
                PosScale.DeviceConnected += MainForm_DeviceConnected;
                PosScale.DeviceDisconnected += MainForm_DeviceDisconnect;
                PosScale.ResultEvent += MainForm_ResultEvent;
                PosScale.WeightEvent += MainForm_WeightEvent;
                PosScale.SendCommandConfirm += MainForm_SendCommandConfirm;
                PosScale.SendResolationConfirm += MainForm_SendResolationConfirm;
            }
            catch { }
        }

        private void MainForm_SendResolationConfirm(object sender, EventArgs e)
        {
            BeginInvoke(new Action(() =>
            {
                ResultText.Text = "عملیات با موفقیت انجام شد";
            }));
        }

        private void MainForm_SendCommandConfirm(object sender, EventArgs e)
        {
            BeginInvoke(new Action(() =>
            {
                ResultText.Text = "عملیات با موفقیت انجام شد";
            }));
        }

        private void MainForm_WeightEvent(object sender, WeightEventArgs e)
        {
            BeginInvoke(new Action(() =>
            {
                WeightSegment.Value = e.Weight;
            }));
        }

        private void MainForm_ResultEvent(object sender, ResultEventArgs e)
        {
            BeginInvoke(new Action(() =>
            {
                ResultText.Text = e.Result;
            }));
        }

        private void MainForm_DeviceDisconnect(object sender, EventArgs e)
        {
            BeginInvoke(new Action(() =>
            {
                ScaleStatus.Text = "ترازو متصل نیست";
                ScaleStatus.ForeColor = Color.Red;
                ResultText.Text = "ارتباط ترازو قطع شد";
                WeightSegment.Value = "";
            }));
        }

        private void MainForm_DeviceConnected(object sender, EventArgs e)
        {
            BeginInvoke(new Action(() =>
            {
                ScaleStatus.Text = "ترازو متصل است";
                ScaleStatus.ForeColor = Color.Green;
                ResultText.Text = "ارتباط ترازو برقرار شد";
            }));
        }

        private void btnDisconnect_Click(object sender, EventArgs e)
        {
            PosScale.DisconnectFromScale();
        }

        private void btnTare_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.Tare);
        }

        private void btnZero_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.Zero);
        }

        private void btnSetting_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.Setting);
        }

        private void btnVersion_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.Version);
        }

        private void btnCalibration_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.Calibration);
        }

        private void btnWeight_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.Weight);
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            PosScale.SendKey(KeyType.OK);
        }

        private void btnResolation_Click(object sender, EventArgs e)
        {
            if (gr2.Checked)
            {
                PosScale.SetResolation(Resolation.g2);
            }
            if (gr5.Checked)
            {
                PosScale.SetResolation(Resolation.g5);
            }
            if (gr10.Checked)
            {
                PosScale.SetResolation(Resolation.g10);
            }
        }
    }
}
